
def determine_chunk_size(num_workers):
    return 2000
